@@ -9,7 +9,7 @@ var searchData=
   ['platformconfig_2eh_6',['PlatformConfig.h',['../PlatformConfig_8h.html',1,'']]],
   ['pnanovdb_2eh_7',['PNanoVDB.h',['../PNanoVDB_8h.html',1,'']]],
   ['pnanovdb_5fvalidate_5fstrides_2eh_8',['pnanovdb_validate_strides.h',['../pnanovdb__validate__strides_8h.html',1,'']]],
-  ['pointadvect_2eh_9',['pointadvect.h',['../tools_2PointAdvect_8h.html',1,'(Global Namespace)'],['../points_2PointAdvect_8h.html',1,'(Global Namespace)']]],
+  ['pointadvect_2eh_9',['PointAdvect.h',['../points_2PointAdvect_8h.html',1,'(Global Namespace)'],['../tools_2PointAdvect_8h.html',1,'(Global Namespace)']]],
   ['pointattribute_2eh_10',['PointAttribute.h',['../PointAttribute_8h.html',1,'']]],
   ['pointattributeimpl_2eh_11',['PointAttributeImpl.h',['../PointAttributeImpl_8h.html',1,'']]],
   ['pointcomputegenerator_2eh_12',['PointComputeGenerator.h',['../PointComputeGenerator_8h.html',1,'']]],
@@ -41,7 +41,7 @@ var searchData=
   ['points_2etxt_38',['points.txt',['../points_8txt.html',1,'']]],
   ['pointsample_2eh_39',['PointSample.h',['../PointSample_8h.html',1,'']]],
   ['pointsampleimpl_2eh_40',['PointSampleImpl.h',['../PointSampleImpl_8h.html',1,'']]],
-  ['pointscatter_2eh_41',['pointscatter.h',['../points_2PointScatter_8h.html',1,'(Global Namespace)'],['../tools_2PointScatter_8h.html',1,'(Global Namespace)']]],
+  ['pointscatter_2eh_41',['PointScatter.h',['../points_2PointScatter_8h.html',1,'(Global Namespace)'],['../tools_2PointScatter_8h.html',1,'(Global Namespace)']]],
   ['pointscatterimpl_2eh_42',['PointScatterImpl.h',['../PointScatterImpl_8h.html',1,'']]],
   ['pointstatistics_2eh_43',['PointStatistics.h',['../PointStatistics_8h.html',1,'']]],
   ['pointstatisticsimpl_2eh_44',['PointStatisticsImpl.h',['../PointStatisticsImpl_8h.html',1,'']]],
