@@ -1,4 +1,4 @@
-var structopenvdb_1_1v12__0_1_1tools_1_1Sampler_3_012_00_01false_01_4 =
+var structopenvdb_1_1v12__0_1_1tools_1_1Sampler_3_010_00_01false_01_4 =
 [
     [ "consistent", "structopenvdb_1_1v12__0_1_1tools_1_1Sampler.html#afd3da75b32679d899a56532f92469c8f", null ],
     [ "mipmap", "structopenvdb_1_1v12__0_1_1tools_1_1Sampler.html#a6c9ddbbbd600c052cade13207665aa39", null ],
@@ -7,6 +7,5 @@ var structopenvdb_1_1v12__0_1_1tools_1_1Sampler_3_012_00_01false_01_4 =
     [ "radius", "structopenvdb_1_1v12__0_1_1tools_1_1Sampler.html#a4836a8d316f4fbaaf3064e0b1acd10ec", null ],
     [ "sample", "structopenvdb_1_1v12__0_1_1tools_1_1Sampler.html#af016e16ec50405c877a06287d54e7c3e", null ],
     [ "sample", "structopenvdb_1_1v12__0_1_1tools_1_1Sampler.html#ac6dc80e2a1753b4c79771e7d4ed37940", null ],
-    [ "staggered", "structopenvdb_1_1v12__0_1_1tools_1_1Sampler.html#a0050bc9dc3e95de2ca035e98149763ed", null ],
-    [ "triquadraticInterpolation", "structopenvdb_1_1v12__0_1_1tools_1_1Sampler_3_012_00_01false_01_4.html#a0861fd17ac9c8cb119b1a4de4617bf83", null ]
+    [ "staggered", "structopenvdb_1_1v12__0_1_1tools_1_1Sampler.html#a0050bc9dc3e95de2ca035e98149763ed", null ]
 ];
\ No newline at end of file
